@@ -62,9 +62,9 @@ import com.google.gwt.user.client.Window;
 import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.gwt.user.client.ui.Anchor;
 import com.google.gwt.user.client.ui.Composite;
-import com.google.gwt.user.client.ui.FlowPanel;
 import com.google.gwt.user.client.ui.FocusPanel;
 import com.google.gwt.user.client.ui.HTMLPanel;
+import com.google.gwt.user.client.ui.HorizontalPanel;
 import com.google.gwt.user.client.ui.SimplePanel;
 import com.google.gwt.user.client.ui.VerticalPanel;
 import com.google.gwt.user.client.ui.Widget;
@@ -110,7 +110,7 @@ public class CreateDatasetForm extends Composite{
 	@UiField Button goBackButtonSecondStep;
 	@UiField Paragraph selectedProfile;
 	@UiField Button goToDatasetButton;
-	@UiField FlowPanel goToDatasetButtonPanel;
+	@UiField HorizontalPanel goToDatasetButtonPanel;
 	@UiField Button addResourcesButton;
 	@UiField SimplePanel workspaceResourcesContainer;
 	@UiField Button continueThirdStep;
@@ -192,8 +192,8 @@ public class CreateDatasetForm extends Composite{
 	// added custom field entries (by the user)
 	private List<CustomFieldEntry> customFieldEntriesList = new ArrayList<CustomFieldEntry>();
 
-	// the list of MetaDataFieldSkeleton added
-	private List<MetaDataFieldSkeleton> listOfMetadataFields = new ArrayList<MetaDataFieldSkeleton>();
+	// the list of MetaDataField added
+	private List<MetaDataField> listOfMetadataFields = new ArrayList<MetaDataField>();
 
 	// dataset metadata bean
 	private DatasetBean receivedBean;
@@ -712,13 +712,22 @@ public class CreateDatasetForm extends Composite{
 
 				if(categories == null || categories.isEmpty()){
 					for (MetadataFieldWrapper field : fields) {
-						MetaDataFieldSkeleton fieldWidget;
+						/*MetaDataFieldSkeleton fieldWidget;
 						try {
 							fieldWidget = new MetaDataFieldSkeleton(field, eventBus);
 							metadataFieldsPanel.add(fieldWidget);
 							listOfMetadataFields.add(fieldWidget);
 						} catch (Exception e) {
 							GWT.log("Unable to build such widget", e);
+						}*/
+						
+						MetaDataField fieldWidget;
+						try {
+							fieldWidget = new MetaDataField(field, eventBus);
+							metadataFieldsPanel.add(fieldWidget);
+							listOfMetadataFields.add(fieldWidget);
+						} catch (Exception e) {
+							GWT.log("Unable to build such widget", e);
 						}
 					}
 				}else{
@@ -731,13 +740,23 @@ public class CreateDatasetForm extends Composite{
 							fields.removeAll(fieldsForThisCategory);
 
 							for (MetadataFieldWrapper metadataFieldWrapper : fieldsForThisCategory) {
-								MetaDataFieldSkeleton fieldWidget;
+								
+								/*MetaDataFieldSkeleton fieldWidget;
 								try {
 									fieldWidget = new MetaDataFieldSkeleton(metadataFieldWrapper, eventBus);
 									cp.addField(fieldWidget);
 									listOfMetadataFields.add(fieldWidget);
 								} catch (Exception e) {
 									GWT.log("Unable to build such widget", e);
+								}*/
+								
+								MetaDataField fieldWidget;
+								try {
+									fieldWidget = new MetaDataField(metadataFieldWrapper, eventBus);
+									cp.addField(fieldWidget);
+									listOfMetadataFields.add(fieldWidget);
+								} catch (Exception e) {
+									GWT.log("Unable to build such widget", e);
 								}
 							}
 							metadataFieldsPanel.add(cp);
@@ -747,13 +766,23 @@ public class CreateDatasetForm extends Composite{
 					// add the remaining one at the end of the categories
 					CategoryPanel extrasCategory = new CategoryPanel("Other", null);
 					for (MetadataFieldWrapper field : fields) {
-						MetaDataFieldSkeleton fieldWidget;
+						
+						/*MetaDataFieldSkeleton fieldWidget;
 						try {
 							fieldWidget = new MetaDataFieldSkeleton(field, eventBus);
 							extrasCategory.addField(fieldWidget);
 							listOfMetadataFields.add(fieldWidget);
 						} catch (Exception e) {
 							GWT.log("Unable to build such widget", e);
+						}*/
+						
+						MetaDataField fieldWidget;
+						try {
+							fieldWidget = new MetaDataField(field, eventBus);
+							extrasCategory.addField(fieldWidget);
+							listOfMetadataFields.add(fieldWidget);
+						} catch (Exception e) {
+							GWT.log("Unable to build such widget", e);
 						}
 					}
 					metadataFieldsPanel.add(extrasCategory);
@@ -930,31 +959,35 @@ public class CreateDatasetForm extends Composite{
 			Map<String, List<String>> customFieldsMap = new HashMap<String, List<String>>();
 
 			// prepare custom fields
-			for (MetaDataFieldSkeleton field : listOfMetadataFields) {
-				List<String> valuesForField = field.getFieldCurrentValue();
-				if(!valuesForField.isEmpty()){
-					String key = field.getFieldNameQualified();
-					List<String> valuesForThisField = null;
-					if(customFieldsMap.containsKey(key))
-						valuesForThisField = customFieldsMap.get(key);
-					else
-						valuesForThisField = new ArrayList<String>();
-
-					valuesForThisField.addAll(valuesForField);
-					customFieldsMap.put(key, valuesForThisField);
-
-					// get also tag/group if it is the case for this field
-					List<String> tagsField = field.getTagFromThisField();
-					if(tagsField != null)
-						tags.addAll(tagsField);
-
-					List<String> groupsTitle = field.getGroupTitleFromThisGroup();
-					if(groupsTitle != null){
-						for (String groupTitle : groupsTitle) {
-							if(field.isGroupToForce())
-								groupsToForceCreation.add(new OrganizationBean(groupTitle, groupTitle, false, field.isPropagateUp()));
-							else
-								groups.add(new OrganizationBean(groupTitle, groupTitle, false, field.isPropagateUp()));
+			for (MetaDataField metaField : listOfMetadataFields) {
+				
+				for (MetaDataFieldSkeleton field : metaField.getListOfMetadataFields()) {
+					
+					List<String> valuesForField = field.getFieldCurrentValue();
+					if(!valuesForField.isEmpty()){
+						String key = field.getFieldNameQualified();
+						List<String> valuesForThisField = null;
+						if(customFieldsMap.containsKey(key))
+							valuesForThisField = customFieldsMap.get(key);
+						else
+							valuesForThisField = new ArrayList<String>();
+	
+						valuesForThisField.addAll(valuesForField);
+						customFieldsMap.put(key, valuesForThisField);
+	
+						// get also tag/group if it is the case for this field
+						List<String> tagsField = field.getTagFromThisField();
+						if(tagsField != null)
+							tags.addAll(tagsField);
+	
+						List<String> groupsTitle = field.getGroupTitleFromThisGroup();
+						if(groupsTitle != null){
+							for (String groupTitle : groupsTitle) {
+								if(field.isGroupToForce())
+									groupsToForceCreation.add(new OrganizationBean(groupTitle, groupTitle, false, field.isPropagateUp()));
+								else
+									groups.add(new OrganizationBean(groupTitle, groupTitle, false, field.isPropagateUp()));
+							}
 						}
 					}
 				}
@@ -1004,19 +1037,27 @@ public class CreateDatasetForm extends Composite{
 
 				@Override
 				public void onSuccess(final DatasetBean createdDatasetBean) {
-
+					
+					GWT.log("Created the dataset: "+createdDatasetBean);
+					
 					if(createdDatasetBean != null){
+						
+						final String datasetUrl = createdDatasetBean.getSource();
 
 						alertOnCreate(PRODUCT_CREATED_OK, AlertType.SUCCESS, false);
-
+			
+						try {
 						// disable dataset fields
-						disableDatasetFields();
+							disableDatasetFields();
+						}catch (Exception e) {
+							// TODO: handle exception
+						}
 
 						// disable reset
 						resetButton.setEnabled(false);
 
 						// show the go to dataset button
-						final String datasetUrl = createdDatasetBean.getSource();
+						
 						goToDatasetButtonPanel.setVisible(true);
 						goToDatasetButton.setVisible(true);
 						goToDatasetButton.setText(
@@ -1032,58 +1073,59 @@ public class CreateDatasetForm extends Composite{
 								//Window.Location.assign(datasetUrl);
 							}
 						});
+	
+						
+						// set hidden the create button
+						createButton.setVisible(false);
 
 						// if we are in the "general case" we need to show a form for adding resources
-						if(isWorkspaceRequest){
-							// leave to back button, but remove create and add go to dataset
-							createButton.removeFromParent();
+						if(!isWorkspaceRequest) {
 
-						}else{
-
-							// remove create button
-							createButton.removeFromParent();
-
-							// show the add resources button
-							addResourcesButton.setVisible(true);
-
-							addResourcesButton.addClickHandler(new ClickHandler() {
-
-								@Override
-								public void onClick(ClickEvent event) {
-
-									// remove content of the main panel
-									createDatasetMainPanel.clear();
-
-									// TabPanel
-									tabPanel = new TabPanel(Tabs.ABOVE);
-									tabPanel.setWidth("100%");
-
-									// add the form
-									resourceForm = new AddResourceToDataset(eventBus, createdDatasetBean.getId(), createdDatasetBean.getSelectedOrganization(), owner, datasetUrl);
-
-									// tab for the form
-									Tab formContainer = new Tab();
-									formContainer.add(resourceForm);
-									formContainer.setHeading("Add New Resource");
-									tabPanel.add(formContainer);
-
-									// tab for the added resources
-									Tab addedResources = new Tab();
-									addedResources.add(new AddedResourcesSummary(eventBus));
-									addedResources.setHeading("Added Resource");
-									tabPanel.add(addedResources);
-
-									// add tabs to resources panel
-									tabPanel.selectTab(0);
-
-									// form container
-									AddResourceContainer container = new AddResourceContainer(datasetUrl);
-									container.add(tabPanel);
-
-									// add the new content of the main panel
-									createDatasetMainPanel.add(container);
-								}
-							});
+							try {
+								// show the add resources button
+								addResourcesButton.setVisible(true);
+	
+								addResourcesButton.addClickHandler(new ClickHandler() {
+	
+									@Override
+									public void onClick(ClickEvent event) {
+	
+										// remove content of the main panel
+										createDatasetMainPanel.clear();
+	
+										// TabPanelException
+										tabPanel = new TabPanel(Tabs.ABOVE);
+										tabPanel.setWidth("100%");
+	
+										// add the form
+										resourceForm = new AddResourceToDataset(eventBus, createdDatasetBean.getId(), createdDatasetBean.getSelectedOrganization(), owner, datasetUrl);
+	
+										// tab for the form
+										Tab formContainer = new Tab();
+										formContainer.add(resourceForm);
+										formContainer.setHeading("Add New Resource");
+										tabPanel.add(formContainer);
+	
+										// tab for the added resources
+										Tab addedResources = new Tab();
+										addedResources.add(new AddedResourcesSummary(eventBus));
+										addedResources.setHeading("Added Resource");
+										tabPanel.add(addedResources);
+	
+										// add tabs to resources panel
+										tabPanel.selectTab(0);
+	
+										// form container
+										AddResourceContainer container = new AddResourceContainer(datasetUrl);
+										container.add(tabPanel);
+	
+										// add the new content of the main panel
+										createDatasetMainPanel.add(container);
+									}
+								});
+							}catch (Exception e2) {
+								//silent
+							}
 						}
 
 					}else{
@@ -1248,14 +1290,17 @@ public class CreateDatasetForm extends Composite{
 	 */
 	private String areProfileDataValid() {
 
-		for (MetaDataFieldSkeleton field : listOfMetadataFields) {
+		for (MetaDataField metaField : listOfMetadataFields) {
+			
+			for (MetaDataFieldSkeleton field : metaField.getListOfMetadataFields()) {
 
-			field.removeError();
-
-			String error = field.isFieldValueValid();
-			if(error != null){
-				field.showError();
-				return field.getFieldNameOriginal() + " is not valid. Suggestion: " + error;
+				field.removeError();
+	
+				String error = field.isFieldValueValid();
+				if(error != null){
+					field.showError();
+					return field.getFieldNameOriginal() + " is not valid. Suggestion: " + error;
+				}
 			}
 		}
 
@@ -1437,8 +1482,11 @@ public class CreateDatasetForm extends Composite{
 			ce.freeze();
 
 		// disable profile fields
-		for (MetaDataFieldSkeleton field : listOfMetadataFields) {
-			field.freeze();
+		for (MetaDataField metaField : listOfMetadataFields) {
+			for (MetaDataFieldSkeleton field : metaField.getListOfMetadataFields()) {
+				field.freeze();
+			}
+			
 		}
 
 		// freeze table of resources
